==> apeman-bud-ci-1.0.5.tgz: package/lib/setup.js <==
/**
 * apeman bud for ci scripts.
 * @memberof module:apeman-bud-ci/lib
 * @function setup
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

var argx = require('argx'),
    async = require('async'),
    arrayreduce = require('arrayreduce'),
    stringcase = require('stringcase'),
    apemanfile = require('apemanfile'),
    path = require('path'),
    fs = require('fs');

function _bud(name, params) {
    return {
        force: false,
        mode: '755',
        mkdirp: true,
        path: name.replace(/[:\$\/]/g, '_').split(/[#]/g).map(function (name) {
            return stringcase.snakecase(name);
        }).join(path.sep) + '.js',
        tmpl: fs.readFileSync(__dirname + '/../asset/tmpl.hbs').toString(),
        data: {
            name: name,
            params: params
        }
    };
}

/** @lends setup */
function setup(params) {
    var args = argx(arguments);
    params = args.shift('object');
    return function bud(callback) {
        async.waterfall([
            function (callback) {
                apemanfile.load(params.configuration, callback);
            },
            function (apemanfile, callback) {
                var $children = apemanfile.$children || {};
                var $tasks = apemanfile.$tasks || {};
                var bud = Object.keys($tasks).map(function (name) {
                    return _bud(name, bud);
                });
                bud = bud.concat(
                    Object.keys($children).map(function (key) {
                        var $child = $children[key];
                        var $tasks = $child.$tasks || {};
                        return Object.keys($tasks).map(function (name) {
                            return _bud([key, name].join('#'), bud);
                        });
                    })
                ).reduce(arrayreduce.arrayConcat(), []);
                callback(null, bud);
            }
        ], callback);
    };
}

module.exports = setup;

==> apeman-bud-ci-2.0.0.tgz: package/lib/setup.js <==
/**
 * apeman bud for ci scripts.
 * @memberof module:apeman-bud-ci/lib
 * @function setup
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    async = require('async'),
    arrayreduce = require('arrayreduce'),
    stringcase = require('stringcase'),
    apemanfile = require('apemanfile'),
    path = require('path'),
    fs = require('fs');

function _bud(name, params) {
    return {
        force: false,
        mode: '755',
        mkdirp: true,
        path: name.replace(/[:\$\/]/g, '_').split(/[#]/g).map((name) => {
            return stringcase.snakecase(name);
        }).join(path.sep) + '.js',
        tmpl: fs.readFileSync(__dirname + '/../asset/tmpl.hbs').toString(),
        data: {
            name: name,
            params: params
        }
    };
}

/** @lends setup */
function setup(params) {
    let args = argx(arguments);
    params = args.shift('object');
    return function bud(callback) {
        async.waterfall([
            (callback) => {
                apemanfile.load(params.configuration, callback);
            },
            (apemanfile, callback) => {
                let $children = apemanfile.$children || {};
                let $tasks = apemanfile.$tasks || {};
                let bud = Object.keys($tasks).map(function (name) {
                    return _bud(name, params);
                });
                bud = bud.concat(
                    Object.keys($children).map(function (key) {
                        let $child = $children[key];
                        let $tasks = $child.$tasks || {};
                        return Object.keys($tasks).map((name) => {
                            return _bud([key, name].join('#'), bud);
                        });
                    })
                ).reduce(arrayreduce.arrayConcat(), []);
                callback(null, bud);
            }
        ], callback);
    };
}

module.exports = setup;
